diff --git a/web/src/App.tsx b/web/src/App.tsx
index 3b2033b1..5da6516b 100644
--- a/web/src/App.tsx
+++ b/web/src/App.tsx
@@ -445,13 +445,15 @@ function App() {
)
}
- // Show landing page for root route
- if (route === '/' || route === '') {
+ // Root route → go to Agent (NOFXi 的主界面就是 Agent)
+ // Landing page only for explicit /landing
+ if (route === '/landing') {
return
}
- // Redirect unauthenticated users to landing page
- if (!user || !token) {
+ // Agent page is accessible without login
+ // Other pages redirect to landing if not authenticated
+ if ((!user || !token) && currentPage !== 'agent') {
return
}